==> kubernetes-model-1.0.0-sources.jar: annotations/io/fabric8/openshift/api/model/NamedTagReferenceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class NamedTagReferenceBuilder extends NamedTagReferenceFluent<NamedTagReferenceBuilder> implements VisitableBuilder<NamedTagReference,NamedTagReferenceBuilder>{

     NamedTagReferenceFluent<?> fluent;
public NamedTagReferenceBuilder(){
    this(new NamedTagReference());
}
public NamedTagReferenceBuilder( NamedTagReferenceFluent<?> fluent ){
    this(fluent, new NamedTagReference());
}
public NamedTagReferenceBuilder( NamedTagReferenceFluent<?> fluent , NamedTagReference instance ){
    this.fluent = fluent; fluent.withAnnotations(instance.getAnnotations()); fluent.withFrom(instance.getFrom()); fluent.withName(instance.getName()); 
}
public NamedTagReferenceBuilder( NamedTagReference instance ){
    this.fluent = this; this.withAnnotations(instance.getAnnotations()); this.withFrom(instance.getFrom()); this.withName(instance.getName()); 
}

public EditableNamedTagReference build(){
    EditableNamedTagReference buildable = new EditableNamedTagReference(fluent.getAnnotations(),fluent.getFrom(),fluent.getName());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.31-sources.jar: annotations/io/fabric8/openshift/api/model/NamedTagReferenceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class NamedTagReferenceBuilder extends NamedTagReferenceFluentImpl<NamedTagReferenceBuilder> implements VisitableBuilder<NamedTagReference,NamedTagReferenceBuilder>{

     NamedTagReferenceFluent<?> fluent;
public NamedTagReferenceBuilder(){
    this(new NamedTagReference());
}
public NamedTagReferenceBuilder( NamedTagReferenceFluent<?> fluent ){
    this(fluent, new NamedTagReference());
}
public NamedTagReferenceBuilder( NamedTagReferenceFluent<?> fluent , NamedTagReference instance ){
    this.fluent = fluent; fluent.withAnnotations(instance.getAnnotations()); fluent.withFrom(instance.getFrom()); fluent.withName(instance.getName()); 
}
public NamedTagReferenceBuilder( NamedTagReference instance ){
    this.fluent = this; this.withAnnotations(instance.getAnnotations()); this.withFrom(instance.getFrom()); this.withName(instance.getName()); 
}

public EditableNamedTagReference build(){
    EditableNamedTagReference buildable = new EditableNamedTagReference(fluent.getAnnotations(),fluent.getFrom(),fluent.getName());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedTagReferenceBuilder that = (NamedTagReferenceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
